ponywhoosh
==========
|PyPI Package latest release| |Test|

Make your database over PonyORM searchable.

Install package, import and start adding what fields of your models in your database, you want to search.

.. image:: https://github.com/jonaprieto/flask-ponywhoosh/blob/master/images/databaseconfig.gif?raw=true
   :target: https://pypi.python.org/pypi/ponywhoosh
   :scale: 70%
   :align: center
   :alt: PonyWhoosh


Please take a look to the official documentation up to date:

    -  http://pythonhosted.org/ponywhoosh/
    -  https://pypi.python.org/pypi/ponywhoosh

Installation
------------

.. code:: python

    pip install ponywhoosh

or use the develop (unstable) version:

.. code:: bash

    git clone https://github.com/jonaprieto/ponywhoosh.git
    cd ponywhoosh
    python setup.py install


.. |PyPI Package latest release| image:: http://img.shields.io/pypi/v/ponywhoosh.png?style=flat
   :target: https://pypi.python.org/pypi/ponywhoosh

.. |Test| image:: https://travis-ci.org/jonaprieto/ponywhoosh.svg?branch=master
    :target: https://travis-ci.org/jonaprieto/ponywhoosh
